@@ -27,7 +27,7 @@ import qualified Data.Text as T
 import qualified Data.Map.Strict as Map
 import General.Util
 import General.Conduit
-import Data.Monoid
+import Data.Semigroup
 import Control.Applicative
 import Prelude
 
@@ -44,12 +44,15 @@ data Package = Package
     ,packageDocs :: Maybe FilePath -- ^ Directory where the documentation is located
     } deriving Show
 
-instance Monoid Package where
-    mempty = Package [] True T.empty T.empty [] Nothing
-    mappend (Package x1 x2 x3 x4 x5 x6) (Package y1 y2 y3 y4 y5 y6) =
+instance Semigroup Package where
+    Package x1 x2 x3 x4 x5 x6 <> Package y1 y2 y3 y4 y5 y6 =
         Package (x1++y1) (x2||y2) (one x3 y3) (one x4 y4) (nubOrd $ x5 ++ y5) (x6 `mplus` y6)
         where one a b = if T.null a then b else a
 
+instance Monoid Package where
+    mempty = Package [] True T.empty T.empty [] Nothing
+    mappend = (<>)
+
 instance NFData Package where
     rnf (Package a b c d e f) = rnf (a,b,c,d,e,f)
 
@@ -96,9 +99,9 @@ parseCabalTarball :: Settings -> FilePath -> IO (Map.Map String Package)
 -- rely on the fact the highest version is last (using lastValues)
 parseCabalTarball settings tarfile = do
     res <- runConduit $
-        (sourceList =<< liftIO (tarballReadFiles tarfile)) =$=
-        mapC (first takeBaseName) =$= groupOnLastC fst =$= mapMC (\x -> do evaluate $ rnf x; return x) =$=
-        pipelineC 10 (mapC (second $ readCabal settings . lstrUnpack) =$= mapMC (\x -> do evaluate $ rnf x; return x) =$= sinkList)
+        (sourceList =<< liftIO (tarballReadFiles tarfile)) .|
+        mapC (first takeBaseName) .| groupOnLastC fst .| mapMC (\x -> do evaluate $ rnf x; return x) .|
+        pipelineC 10 (mapC (second $ readCabal settings . lstrUnpack) .| mapMC (\x -> do evaluate $ rnf x; return x) .| sinkList)
     return $ Map.fromList res
 
 
