@@ -1,5 +1,4 @@
 {-# LANGUAGE TupleSections #-}
-{-# OPTIONS_GHC -fno-warn-warnings-deprecations #-} -- Use conduitManagerSettings to work with http-conduit-2.1.6 and below
 
 module Input.Download(downloadInput) where
 
@@ -31,8 +30,8 @@ downloadInput timing insecure download dir name url = do
 
 downloadFile :: Bool -> FilePath -> String -> IO ()
 downloadFile insecure file url = withSocketsDo $ do
-    request <- C.parseUrl url
+    let request = C.parseRequest_ url
     manager <- C.newManager $ C.mkManagerSettings (TLSSettingsSimple insecure False False) Nothing
     runResourceT $ do
         response <- C.http request manager
-        C.responseBody response C.$$+- sinkFile file
+        C.runConduit $ C.responseBody response C..| sinkFile file
